cosmic\_ray.commands package
============================

Submodules
----------

cosmic\_ray.commands.execute module
-----------------------------------

.. automodule:: cosmic_ray.commands.execute
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.commands.init module
--------------------------------

.. automodule:: cosmic_ray.commands.init
   :members:
   :undoc-members:
   :show-inheritance:

cosmic\_ray.commands.new\_config module
---------------------------------------

.. automodule:: cosmic_ray.commands.new_config
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cosmic_ray.commands
   :members:
   :undoc-members:
   :show-inheritance:
